@@ -65,11 +65,11 @@ class ThetaService(object):
             # raise ValueError('The given timestamp range does not cover any blocks')
 
         start_block = 1#start_block_bounds[1]
-        end_block = 6807304#end_block_bounds[0]
+        end_block = 200#end_block_bounds[0]
 
         # The genesis block has timestamp 0 but we include it with the 1st block.
-        if start_block == 1:
-            start_block = 0
+        # if start_block == 1:
+        #     start_block = 0
 
         return start_block, end_block
 
